x86-arch.o x86-arch.d : x86-arch.c genesis/sbcl.h runtime.h lispobj.h align.h \
 globals.h os.h target-os.h target-arch-os.h target-arch.h interr.h \
 validate.h thread.h genesis/symbol.h lispobj.h symbol-tls.inc align.h \
 genesis/vector.h genesis/static-symbols.h genesis/static-symbols.h \
 genesis/thread.h gencgc-alloc-region.h genesis/vector.h interrupt.h \
 gc-typedefs.h arch.h lispregs.h target-lispregs.h genesis/regnames.h \
 breakpoint.h pseudo-atomic.h gc.h gc-assert.h immobile-space.h \
 gencgc-impl.h gencgc-alloc-region.h genesis/cardmarks.h genesis/cons.h \
 genesis/weak-pointer.h hopscotch.h code.h genesis/closure.h \
 forwarding-ptr.inc var-io.h x86-arch-shared.inc
