/*
 * This is a machine-generated file. Please do not edit it by hand.
 *
 * This file contains low-level information about the
 * internals of a particular version and configuration
 * of SBCL. It is used by the C compiler to create a runtime
 * support environment, an executable program in the host
 * operating system's native format, which can then be used to
 * load and run 'core' files, which are basically programs
 * in SBCL's own format.
 */
#ifndef SBCL_GENESIS_STATIC_SYMBOLS
#define SBCL_GENESIS_STATIC_SYMBOLS
#define NIL LISPOBJ(0x110000B)
#define LISP_T LISPOBJ(0x110002F)
#define CURRENT_CATCH_BLOCK LISPOBJ(0x110004F)
#define CURRENT_UNWIND_PROTECT_BLOCK LISPOBJ(0x110006F)
#define IMMOBILE_CODEBLOB_TREE LISPOBJ(0x110008F)
#define IMMOBILE_CODEBLOB_VECTOR LISPOBJ(0x11000AF)
#define DYNSPACE_CODEBLOB_TREE LISPOBJ(0x11000CF)
#define LINKAGE_NAME_MAP LISPOBJ(0x11000EF)
#define FINALIZER_STORE LISPOBJ(0x110010F)
#define FINALIZER_REHASHLIST LISPOBJ(0x110012F)
#define FINALIZERS_TRIGGERED LISPOBJ(0x110014F)
#define RUN_GC_HOOKS LISPOBJ(0x110016F)
#define STARTING_THREADS LISPOBJ(0x110018F)
#define FREE_TLS_INDEX LISPOBJ(0x11001AF)
#define TLS_SYMBOL_MAP LISPOBJ(0x11001CF)
#define GC_EPOCH LISPOBJ(0x11001EF)
#define DATA_VECTOR_REFFERS LISPOBJ(0x110020F)
#define DATA_VECTOR_REFFERS_CHECK_BOUNDS LISPOBJ(0x110022F)
#define DATA_VECTOR_SETTERS LISPOBJ(0x110024F)
#define DATA_VECTOR_SETTERS_CHECK_BOUNDS LISPOBJ(0x110026F)
#define ALIEN_STACK_POINTER LISPOBJ(0x110028F)
#define PSEUDO_ATOMIC_BITS LISPOBJ(0x11002AF)
#define BINDING_STACK_POINTER LISPOBJ(0x11002CF)
#define FP_CONSTANT_0D0 LISPOBJ(0x11002EF)
#define FP_CONSTANT_1D0 LISPOBJ(0x110030F)
#define FP_CONSTANT_0F0 LISPOBJ(0x110032F)
#define FP_CONSTANT_1F0 LISPOBJ(0x110034F)
#define FP_CONSTANT_0L0 LISPOBJ(0x110036F)
#define FP_CONSTANT_1L0 LISPOBJ(0x110038F)
#define FP_CONSTANT_PI LISPOBJ(0x11003AF)
#define FP_CONSTANT_L2T LISPOBJ(0x11003CF)
#define FP_CONSTANT_L2E LISPOBJ(0x11003EF)
#define FP_CONSTANT_LG2 LISPOBJ(0x110040F)
#define FP_CONSTANT_LN2 LISPOBJ(0x110042F)
#define LFLIST_TAIL_ATOM LISPOBJ(0x1100449)
#define SUB_GC_FDEFN LISPOBJ(0x110045F)
#define POST_GC_FDEFN LISPOBJ(0x110046F)
#define INTERNAL_ERROR_FDEFN LISPOBJ(0x110047F)
#define CONTROL_STACK_EXHAUSTED_ERROR_FDEFN LISPOBJ(0x110048F)
#define BINDING_STACK_EXHAUSTED_ERROR_FDEFN LISPOBJ(0x110049F)
#define ALIEN_STACK_EXHAUSTED_ERROR_FDEFN LISPOBJ(0x11004AF)
#define HEAP_EXHAUSTED_ERROR_FDEFN LISPOBJ(0x11004BF)
#define UNDEFINED_ALIEN_VARIABLE_ERROR_FDEFN LISPOBJ(0x11004CF)
#define MEMORY_FAULT_ERROR_FDEFN LISPOBJ(0x11004DF)
#define UNHANDLED_TRAP_ERROR_FDEFN LISPOBJ(0x11004EF)
#define UNDEFINED_ALIEN_FUN_ERROR_FDEFN LISPOBJ(0x11004FF)
#define HANDLE_BREAKPOINT_FDEFN LISPOBJ(0x110050F)
#define HANDLE_SINGLE_STEP_TRAP_FDEFN LISPOBJ(0x110051F)
#define ENTER_ALIEN_CALLBACK_FDEFN LISPOBJ(0x110052F)
#define ENTER_FOREIGN_CALLBACK_FDEFN LISPOBJ(0x110053F)
#define FREE_INTERRUPT_CONTEXT_INDEX (*)
#define FREE_INTERRUPT_CONTEXT_INDEX_tlsindex 0xC0
#define ALLOW_WITH_INTERRUPTS (*)
#define ALLOW_WITH_INTERRUPTS_tlsindex 0xC4
#define INTERRUPTS_ENABLED (*)
#define INTERRUPTS_ENABLED_tlsindex 0xC8
#define INTERRUPT_PENDING (*)
#define INTERRUPT_PENDING_tlsindex 0xCC
#define IN_WITHOUT_GCING (*)
#define IN_WITHOUT_GCING_tlsindex 0xD0
#define GC_INHIBIT (*)
#define GC_INHIBIT_tlsindex 0xD4
#define GC_PENDING (*)
#define GC_PENDING_tlsindex 0xD8
#define STOP_FOR_GC_PENDING (*)
#define STOP_FOR_GC_PENDING_tlsindex 0xDC
#define UNWEAKENED_VECTORS (*)
#define UNWEAKENED_VECTORS_tlsindex 0xE0
#define PINNED_OBJECTS (*)
#define PINNED_OBJECTS_tlsindex 0xE4
#define GC_PIN_CODE_PAGES (*)
#define GC_PIN_CODE_PAGES_tlsindex 0xE8
#define CURRENT_CATCH_BLOCK_tlsindex 0xEC
#define CURRENT_UNWIND_PROTECT_BLOCK_tlsindex 0xF0
#endif
