traceroot.o traceroot.d : traceroot.c genesis/sbcl.h arch.h os.h runtime.h lispobj.h \
 align.h target-os.h target-arch-os.h target-arch.h interr.h thread.h \
 globals.h genesis/symbol.h lispobj.h symbol-tls.inc align.h \
 genesis/vector.h genesis/static-symbols.h genesis/static-symbols.h \
 genesis/thread.h gencgc-alloc-region.h genesis/vector.h interrupt.h \
 validate.h gc-typedefs.h lispregs.h target-lispregs.h genesis/regnames.h \
 gc.h gc-assert.h immobile-space.h gencgc-impl.h gencgc-alloc-region.h \
 genesis/cardmarks.h genesis/cons.h genesis/weak-pointer.h hopscotch.h \
 code.h genesis/closure.h forwarding-ptr.inc genesis/gc-tables.h \
 genesis/hash-table.h genesis/instance.h instance.inc genesis/package.h \
 search.h genesis/sap.h print.h
